"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _core = require("@sheets-editor/core");

var _isHotkey = _interopRequireDefault(require("is-hotkey"));

var _slateReact = require("slate-react");

var _createDecorator = require("./createDecorator");

var _ElementCode = _interopRequireDefault(require("./ElementCode"));

var _LeafCode = _interopRequireDefault(require("./LeafCode"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const CodePlugin = (options = {}) => editor => {
  let blockType = 'code';

  if (options.block && options.block.type) {
    blockType = options.block.type;
  }

  function setBlockLanguage(element, language) {
    const path = _slateReact.ReactEditor.findPath(editor, element);

    _core.Transforms.setNodes(editor, {
      language
    }, {
      at: path
    });
  }

  return {
    onKeyDown: event => {
      if ((0, _isHotkey.default)('Tab', event)) {
        const parent = (0, _core.getBlockAbove)(editor);

        if (parent[0].type === 'code') {
          event.preventDefault();
          editor.insertText('  ');
        }
      }
    },
    decorate: (0, _createDecorator.createDecorator)(editor, blockType),
    renderLeaf: ({
      attributes,
      children,
      leaf
    }) => {
      if (leaf.decorateCode) {
        return _react.default.createElement("span", _extends({}, attributes, {
          className: `token ${leaf.token}`
        }), children);
      }

      return children;
    },
    elements: [{
      type: blockType,
      component: props => _react.default.createElement(_ElementCode.default, _extends({}, props, {
        onSetLanguage: setBlockLanguage
      })),
      returnBehaviour: 'soft-break',
      ...(options.block || {})
    }],
    leaves: [{
      mark: 'code',
      component: _LeafCode.default,
      shortcuts: [{
        start: '`',
        end: '`'
      }]
    }]
  };
};

var _default = CodePlugin;
exports.default = _default;
//# sourceMappingURL=CodePlugin.js.map